# package_name

Description. 
The package image_processing is used to:
	Processing:
		- Histogram matching
		- Structurall similarity
		- Resize image
	Utills:
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histogram	

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install -i https://test.pypi.org/simple/ image-processing-ld
```


## Author
Lucas Dionisio

## License
[MIT](https://choosealicense.com/licenses/mit/)